@@ -2,6 +2,7 @@
 
 """API for :mod:`chembl_downloader`."""
 
+import gzip
 import logging
 import os
 import sqlite3
@@ -16,10 +17,12 @@ if TYPE_CHECKING:
     import pandas
 
 __all__ = [
-    "download",
+    "latest",
+    "download_extract_sqlite",
     "connect",
     "cursor",
     "query",
+    "supplier",
 ]
 
 logger = logging.getLogger(__name__)
@@ -28,7 +31,38 @@ logger = logging.getLogger(__name__)
 PYSTOW_PARTS = ["chembl"]
 
 
+def latest() -> str:
+    """Get the latest version of ChEBML as a string.
+
+    :returns: The latest version string of ChEBML
+    :raises ImportError: If :mod:`bioversions` is not installed.
+    """
+    try:
+        import bioversions
+    except ImportError:
+        raise ImportError("Could not import `bioversions`. Install with `pip install bioversions`.")
+    else:
+        return bioversions.get_version("chembl")
+
+
 def _download_helper(
+    suffix: str, version: Optional[str] = None, prefix: Optional[Sequence[str]] = None
+) -> Tuple[str, Path]:
+    """Ensure the latest ChEMBL file with the given suffix is downloaded.
+
+    :param suffix: The suffix of the file
+    :param version: The version number of ChEMBL to get. If none specified, uses
+        :func:`bioversions.get_version` to look up the latest.
+    :param prefix: The directory inside :mod:`pystow` to use
+    :return: A pair of the version and the path to the downloaded tar.gz file
+    """
+    if version is None:
+        version = latest()
+    url = f"ftp://ftp.ebi.ac.uk/pub/databases/chembl/ChEMBLdb/releases/chembl_{version}/chembl_{version}{suffix}"
+    return version, pystow.ensure(*(prefix or PYSTOW_PARTS), version, url=url)
+
+
+def download_sqlite(
     version: Optional[str] = None, prefix: Optional[Sequence[str]] = None
 ) -> Tuple[str, Path]:
     """Ensure the latest ChEMBL SQLite dump is downloaded.
@@ -36,18 +70,15 @@ def _download_helper(
     :param version: The version number of ChEMBL to get. If none specified, uses
         :func:`bioversions.get_version` to look up the latest.
     :param prefix: The directory inside :mod:`pystow` to use
-    :return: A pair of the version and the path to the downloaded tar.gz file
+    :return: A pair of the version and the local file path to the downloaded *.tar.gz file
     """
-    if version is None:
-        import bioversions
-
-        version = bioversions.get_version("chembl")
-    url = f"ftp://ftp.ebi.ac.uk/pub/databases/chembl/ChEMBLdb/releases/chembl_{version}/chembl_{version}_sqlite.tar.gz"
-    return version, pystow.ensure(*(prefix or PYSTOW_PARTS), version, url=url)
+    return _download_helper(suffix="_sqlite.tar.gz", version=version, prefix=prefix)
 
 
-def download(version: Optional[str] = None, prefix: Optional[Sequence[str]] = None) -> Path:
-    """Get a connection as a context to the ChEMBL database.
+def download_extract_sqlite(
+    version: Optional[str] = None, prefix: Optional[Sequence[str]] = None
+) -> Path:
+    """Ensure the latest ChEMBL SQLite dump is downloaded and extracted.
 
     :param version: The version number of ChEMBL to get. If none specified, uses
         :func:`bioversions.get_version` to look up the latest.
@@ -56,7 +87,7 @@ def download(version: Optional[str] = None, prefix: Optional[Sequence[str]] = No
     :raises FileNotFoundError: If no database file could be found in the
         extracted directories
     """
-    version, path = _download_helper(version=version, prefix=prefix)
+    version, path = download_sqlite(version=version, prefix=prefix)
 
     # Extraction will be done in the same directory as the download.
     # All ChEMBL SQLite dumps have the same internal folder structure,
@@ -98,7 +129,7 @@ def connect(version: Optional[str] = None, prefix: Optional[Sequence[str]] = Non
             with closing(conn.cursor()) as cursor:
                 cursor.execute(...)
     """
-    path = download(version=version, prefix=prefix)
+    path = download_extract_sqlite(version=version, prefix=prefix)
     with closing(sqlite3.connect(path.as_posix())) as conn:
         yield conn
 
@@ -126,16 +157,16 @@ def cursor(version: Optional[str] = None, prefix: Optional[Sequence[str]] = None
 
 
 def query(
-    q: str, version: Optional[str] = None, prefix: Optional[Sequence[str]] = None, **kwargs
+    sql: str, version: Optional[str] = None, prefix: Optional[Sequence[str]] = None, **kwargs
 ) -> "pandas.DataFrame":
     """Ensure the data is available, run the query, then put the results in a dataframe.
 
-    :param q: A SQL query string
+    :param sql: A SQL query string or table name
     :param version: The version number of ChEMBL to get. If none specified, uses
         :func:`bioversions.get_version` to look up the latest.
     :param prefix: The directory inside :mod:`pystow` to use
-    :param kwargs: keyword arguments to pass through to :class:`pandas.DataFrame`, such as
-        ``columns`` or ``index``.
+    :param kwargs: keyword arguments to pass through to :func:`pandas.read_sql`, such as
+        ``index_col``.
     :return: A dataframe
 
     Example:
@@ -144,10 +175,59 @@ def query(
         import chembl_downloader
         from chembl_downloader.queries import ID_NAME_QUERY_EXAMPLE
 
-        df = chembl_downloader.query(ID_NAME_QUERY_EXAMPLE, columns=['chembl_id', 'name'])
+        df = chembl_downloader.query(ID_NAME_QUERY_EXAMPLE)
     """
     import pandas as pd
 
-    with cursor(version=version, prefix=prefix) as _cursor:
-        _cursor.execute(q)
-        return pd.DataFrame(_cursor.fetchall(), **kwargs)
+    with connect(version=version, prefix=prefix) as con:
+        return pd.read_sql(sql, con=con, **kwargs)
+
+
+def download_sdf(
+    version: Optional[str] = None, prefix: Optional[Sequence[str]] = None
+) -> Tuple[str, Path]:
+    """Ensure the latest ChEMBL SDF dump is downloaded.
+
+    :param version: The version number of ChEMBL to get. If none specified, uses
+        :func:`bioversions.get_version` to look up the latest.
+    :param prefix: The directory inside :mod:`pystow` to use
+    :return: A pair of the version and the local file path to the downloaded *.sdf.gz file
+    """
+    return _download_helper(suffix=".sdf.gz", version=version, prefix=prefix)
+
+
+@contextmanager
+def supplier(
+    version: Optional[str] = None,
+    prefix: Optional[Sequence[str]] = None,
+    **kwargs,
+):
+    """Get a :class:`rdkit.Chem.ForwardSDMolSupplier` for the given version of ChEMBL.
+
+    :param version: The version number of ChEMBL to get. If none specified, uses
+        :func:`bioversions.get_version` to look up the latest.
+    :param prefix: The directory inside :mod:`pystow` to use
+    :param kwargs: keyword arguments to pass through to :class:`rdkit.Chem.ForwardSDMolSupplier`, such as
+        ``sanitize`` and ``removeHs``.
+
+    Example:
+    .. code-block:: python
+
+        from rdkit import Chem
+
+        import chembl_downloader
+
+        data = []
+        with chembl_downloader.supplier() as suppl:
+            for i, mol in enumerate(suppl):
+                if mol is None or mol.GetNumAtoms() > 50:
+                    continue
+                fp = Chem.PatternFingerprint(mol, fpSize=1024, tautomerFingerprints=True)
+                smi = Chem.MolToSmiles(mol)
+                data.append((smi, fp))
+    """
+    from rdkit import Chem
+
+    _, path = download_sdf(version=version, prefix=prefix)
+    with gzip.open(path) as file:
+        yield Chem.ForwardSDMolSupplier(file, **kwargs)
